function [ B ] = incidence( M )
%INCIDENCE Builds signed vertex-to-halfedge incidence matrix of mesh M
%   Returns m-by-n matrix B, where m is the number of halfedges edges
%   and n is the number of vertices.
%   B(i,j)==1 iff halfedge i is positively incident with vertex j,
%   B(i,j)==-1 iff halfedge i is negatively incident with vertex j and
%   B(i,j)==0 otherwise.

%A = adjacency(M);
%[I,J] = find(triu(A));
%numberOfEdges = size(I,1);
%B1 = sparse([(1:numberOfEdges)';(1:numberOfEdges)'],[I;J], 1.0);

IFrom = [M.tri(:,1);M.tri(:,2);M.tri(:,3)];
ITo = [M.tri(:,2);M.tri(:,3);M.tri(:,1)];
numberOfEdges = size(IFrom,1);
B = sparse(1:numberOfEdges,IFrom, -1.0)+sparse(1:numberOfEdges,ITo, 1.0);
end

